@@ -15,11 +15,11 @@ use tokio::net::TcpStream;
 use tokio::sync::mpsc;
 use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 #[cfg(target_arch = "wasm32")]
-use wasm_bus::ws::RecvHalf as WasmRecvHalf;
+use wasm_bus_ws::prelude::RecvHalf as WasmRecvHalf;
 #[cfg(target_arch = "wasm32")]
-use wasm_bus::ws::SendHalf as WasmSendHalf;
+use wasm_bus_ws::prelude::SendHalf as WasmSendHalf;
 #[cfg(target_arch = "wasm32")]
-use wasm_bus::ws::WebSocket as WasmWebSocket;
+use wasm_bus_ws::prelude::WebSocket as WasmWebSocket;
 
 use crate::comms::PacketData;
 use crate::crypto::EncryptKey;
@@ -326,7 +326,6 @@ impl Stream {
 }
 
 impl StreamTx {
-    #[must_use = "all network communication metrics must be accounted for"]
     #[allow(unused_variables)]
     pub async fn write_8bit(
         &mut self,
@@ -379,7 +378,6 @@ impl StreamTx {
         Ok(total_sent)
     }
 
-    #[must_use = "all network communication metrics must be accounted for"]
     #[allow(unused_variables)]
     pub async fn write_16bit(
         &mut self,
@@ -432,7 +430,6 @@ impl StreamTx {
         Ok(total_sent)
     }
 
-    #[must_use = "all network communication metrics must be accounted for"]
     #[allow(unused_variables)]
     pub async fn write_32bit(
         &mut self,
@@ -565,7 +562,6 @@ impl StreamTx {
         }
     }
 
-    #[must_use = "all network communication metrics must be accounted for"]
     pub(crate) async fn send(
         &mut self,
         wire_encryption: &Option<EncryptKey>,
@@ -602,7 +598,6 @@ impl StreamTxChannel {
         }
     }
 
-    #[must_use = "all network communication metrics must be accounted for"]
     pub(crate) async fn send(&mut self, pck: PacketData) -> Result<u64, tokio::io::Error> {
         self.tx.send(&self.wire_encryption, pck).await
     }
