@@ -1,19 +1,17 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use fxhash::FxHashSet;
-use crate::event::*;
 use crate::crypto::*;
+use crate::event::*;
+use fxhash::FxHashSet;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 use super::*;
 
 #[derive(Default, Clone)]
-pub struct PublicKeyCompactor
-{
+pub struct PublicKeyCompactor {
     sign_with: FxHashSet<AteHash>,
 }
 
-impl PublicKeyCompactor
-{
+impl PublicKeyCompactor {
     pub fn new() -> PublicKeyCompactor {
         PublicKeyCompactor {
             sign_with: FxHashSet::default(),
@@ -21,15 +19,12 @@ impl PublicKeyCompactor
     }
 }
 
-impl EventCompactor
-for PublicKeyCompactor
-{
+impl EventCompactor for PublicKeyCompactor {
     fn clone_compactor(&self) -> Option<Box<dyn EventCompactor>> {
         Some(Box::new(Self::default()))
     }
-    
-    fn relevance(&self, header: &EventHeader) -> EventRelevance
-    {
+
+    fn relevance(&self, header: &EventHeader) -> EventRelevance {
         if let Some(pk) = header.meta.get_public_key() {
             let pk_hash = pk.hash();
             if self.sign_with.contains(&pk_hash) {
@@ -56,4 +51,4 @@ for PublicKeyCompactor
     fn name(&self) -> &str {
         "public-key-compactor"
     }
-}
\ No newline at end of file
+}
