@@ -1,6 +1,6 @@
+use serde::{Deserialize, Serialize};
 #[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use serde::{Serialize, Deserialize};
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 use super::*;
 
@@ -22,4 +22,4 @@ impl DoubleHash {
     pub fn hash(&self) -> AteHash {
         AteHash::from_bytes_twice(&self.hash1.val[..], &self.hash2.val[..])
     }
-}
\ No newline at end of file
+}
