@@ -1,7 +1,7 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 use std::result::Result;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 /// Size of a cryptographic key, smaller keys are still very secure but
 /// have less room in the future should new attacks be found against the
@@ -17,8 +17,7 @@ pub enum KeySize {
     Bit256 = 32,
 }
 
-impl KeySize
-{
+impl KeySize {
     pub fn as_str(&self) -> &str {
         match &self {
             KeySize::Bit128 => "128",
@@ -28,9 +27,7 @@ impl KeySize
     }
 }
 
-impl std::str::FromStr
-for KeySize
-{
+impl std::str::FromStr for KeySize {
     type Err = &'static str;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
@@ -43,9 +40,7 @@ for KeySize
     }
 }
 
-impl std::fmt::Display
-for KeySize
-{
+impl std::fmt::Display for KeySize {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
             KeySize::Bit128 => write!(f, "128"),
@@ -53,4 +48,4 @@ for KeySize
             KeySize::Bit256 => write!(f, "256"),
         }
     }
-}
\ No newline at end of file
+}
