@@ -149,6 +149,10 @@ impl Dio {
         &self.chain
     }
 
+    pub fn remote<'a>(&'a self) -> Option<&'a url::Url> {
+        self.chain.remote()
+    }
+
     async fn run_async<F>(&self, future: F) -> F::Output
     where
         F: std::future::Future,
@@ -301,6 +305,19 @@ impl Dio {
         Ok(keys)
     }
 
+    pub async fn root_keys(
+        self: &Arc<Self>,
+    ) -> Vec<PrimaryKey> {
+        self.run_async(self.__root_keys())
+            .await
+    }
+
+    pub async fn __root_keys(
+        self: &Arc<Self>,
+    ) -> Vec<PrimaryKey> {
+        self.multi.roots_raw().await
+    }
+
     pub async fn all_keys(self: &Arc<Self>) -> Vec<PrimaryKey> {
         self.run_async(self.__all_keys()).await
     }
@@ -363,6 +380,50 @@ impl Dio {
             .await?)
     }
 
+    pub async fn roots<D>(
+        self: &Arc<Self>,
+    ) -> Result<Vec<Dao<D>>, LoadError>
+    where
+        D: DeserializeOwned,
+    {
+        self.roots_ext(false, false)
+            .await
+    }
+
+    pub async fn roots_ext<D>(
+        self: &Arc<Self>,
+        allow_missing_keys: bool,
+        allow_serialization_error: bool,
+    ) -> Result<Vec<Dao<D>>, LoadError>
+    where
+        D: DeserializeOwned,
+    {
+        self.run_async(self.__roots_ext(
+            allow_missing_keys,
+            allow_serialization_error,
+        ))
+        .await
+    }
+
+    pub(super) async fn __roots_ext<D>(
+        self: &Arc<Self>,
+        allow_missing_keys: bool,
+        allow_serialization_error: bool,
+    ) -> Result<Vec<Dao<D>>, LoadError>
+    where
+        D: DeserializeOwned,
+    {
+        // Load all the objects
+        let keys = self.__root_keys().await;
+        Ok(self
+            .__load_many_ext(
+                keys.into_iter(),
+                allow_missing_keys,
+                allow_serialization_error,
+            )
+            .await?)
+    }
+
     pub async fn load_many<D>(
         self: &Arc<Self>,
         keys: impl Iterator<Item = PrimaryKey>,
@@ -549,7 +610,7 @@ impl Dio {
         TaskEngine::spawn(async move {
             loop {
                 let recv =
-                    crate::engine::timeout(std::time::Duration::from_secs(1), decache.recv()).await;
+                    crate::engine::timeout(std::time::Duration::from_secs(5), decache.recv()).await;
                 let dio = match Weak::upgrade(&dio) {
                     Some(a) => a,
                     None => {
@@ -564,15 +625,30 @@ impl Dio {
                 };
                 let recv = match recv {
                     Ok(a) => a,
-                    Err(_) => {
+                    Err(broadcast::error::RecvError::Closed) => {
                         break;
                     }
+                    Err(broadcast::error::RecvError::Lagged(_)) => {
+                        continue;
+                    }
                 };
 
                 let mut state = dio.state.lock().unwrap();
                 for key in recv {
                     state.cache_load.remove(&key);
                 }
+                loop {
+                    match decache.try_recv() {
+                        Ok(recv) => {
+                            for key in recv {
+                                state.cache_load.remove(&key);
+                            }
+                        }
+                        Err(_) => {
+                            break;
+                        }
+                    }
+                }
             }
         });
     }
