@@ -1,7 +1,7 @@
-use error_chain::error_chain;
-use std::{time::SystemTime};
-use chrono::Utc;
 use chrono::DateTime;
+use chrono::Utc;
+use error_chain::error_chain;
+use std::time::SystemTime;
 
 use std::time::SystemTimeError;
 
@@ -29,4 +29,4 @@ error_chain! {
                     DateTime::<Utc>::from(*timestamp).format("%Y-%m-%d %H:%M:%S.%f").to_string())
         }
     }
-}
\ No newline at end of file
+}
