@@ -204,24 +204,6 @@ impl MeshRoot {
         Ok(root)
     }
 
-    pub async fn accept_stream(
-        &self,
-        stream: Stream,
-        sock_addr: SocketAddr,
-    ) -> Result<(), CommsError> {
-        let listener = {
-            let guard = self.listener.lock().unwrap();
-            if let Some(listener) = guard.as_ref() {
-                Arc::clone(&listener)
-            } else {
-                warn!("listener is inactive - lost stream");
-                bail!(CommsErrorKind::Refused);
-            }
-        };
-        Listener::accept_stream(listener, stream, sock_addr, self.exit.subscribe()).await?;
-        Ok(())
-    }
-
     async fn auto_clean(self: Arc<Self>) {
         let chain = Arc::downgrade(&self);
         loop {
@@ -317,6 +299,10 @@ impl MeshRoot {
         }
     }
 
+    pub fn server_id(&self) -> NodeId {
+        self.server_id.clone()
+    }
+
     pub async fn shutdown(self: &Arc<Self>) {
         TaskEngine::run_until(
             self.__shutdown()
@@ -348,6 +334,32 @@ impl MeshRoot {
     }
 }
 
+#[async_trait]
+impl StreamRoute
+for MeshRoot
+{
+    async fn accepted_web_socket(
+        &self,
+        rx: StreamRx,
+        tx: Upstream,
+        hello: HelloMetadata,
+        sock_addr: SocketAddr,
+        wire_encryption: Option<EncryptKey>,
+    ) -> Result<(), CommsError> {
+        let listener = {
+            let guard = self.listener.lock().unwrap();
+            if let Some(listener) = guard.as_ref() {
+                Arc::clone(&listener)
+            } else {
+                warn!("listener is inactive - lost stream");
+                bail!(CommsErrorKind::Refused);
+            }
+        };
+        Listener::accept_stream(listener, rx, tx, hello, wire_encryption, sock_addr, self.exit.subscribe()).await?;
+        Ok(())
+    }
+}
+
 fn disconnected(mut context: SessionContextProtected) -> Result<(), CommsError> {
     if let Some(chain) = context.chain {
         for key in context.locks.iter() {
@@ -559,7 +571,7 @@ impl ServerProcessor<Message, SessionContext> for MeshRootProcessor {
     }
 
     async fn shutdown(&self, addr: SocketAddr) {
-        info!("disconnected: {}", addr.to_string());
+        debug!("disconnected: {}", addr.to_string());
     }
 }
 
@@ -865,9 +877,9 @@ async fn inbox_packet<'b>(
         let pck_data = pck.data;
         let pck = pck.packet;
 
-        let read_only = {
+        let delete_only = {
             let throttle = tx.throttle.lock().unwrap();
-            throttle.read_only
+            throttle.delete_only
         };
 
         match pck.msg {
@@ -890,17 +902,18 @@ async fn inbox_packet<'b>(
                 .await?;
             }
             Message::Events { commit, evts } => {
-                if read_only {
-                    debug!("event aborted - channel is currently read-only");
-                    tx.send_reply_msg(Message::ReadOnly).await?;
-                    return Ok(());
-                }
-
                 let num_deletes = evts
                     .iter()
                     .filter(|a| a.meta.get_tombstone().is_some())
                     .count();
                 let num_data = evts.iter().filter(|a| a.data.is_some()).count();
+
+                if delete_only && num_data > 0 {
+                    debug!("event aborted - channel is currently read-only");
+                    tx.send_reply_msg(Message::ReadOnly).await?;
+                    return Ok(());
+                }
+
                 inbox_event(context, commit, evts, tx, pck_data)
                     .instrument(span!(
                         Level::DEBUG,
