@@ -55,6 +55,7 @@ impl MeshSession {
         builder: ChainBuilder,
         cfg_mesh: &ConfMesh,
         chain_key: &ChainKey,
+        remote: url::Url,
         addr: MeshAddress,
         node_id: NodeId,
         hello_path: String,
@@ -95,6 +96,7 @@ impl MeshSession {
                 TrustMode::Distributed,
             )
             .await?;
+            chain.remote = Some(remote);
             chain.remote_addr = Some(addr.clone());
             chain
         };
@@ -446,6 +448,8 @@ impl MeshSession {
         #[cfg(feature = "enable_super_verbose")]
         trace!("packet size={}", pck.data.bytes.len());
 
+        //trace!("packet(size={} msg={:?})", pck.data.bytes.len(), pck.packet.msg);
+
         match pck.packet.msg {
             Message::StartOfHistory {
                 size,
@@ -471,12 +475,19 @@ impl MeshSession {
                 self.cancel_commits(CommitErrorKind::ReadOnly).await;
                 let _ = self.status_tx.send(ConnectionStatusChange::ReadOnly).await;
             }
-            Message::Events { commit: _, evts } => {
+            Message::Events { commit, evts } => {
                 let num_deletes = evts
                     .iter()
                     .filter(|a| a.meta.get_tombstone().is_some())
                     .count();
                 let num_data = evts.iter().filter(|a| a.data.is_some()).count();
+                let ret2 = if let Some(id) = commit {
+                    Self::inbox_confirmed(self, id)
+                        .instrument(span!(Level::DEBUG, "commit-confirmed"))
+                        .await
+                } else {
+                    Result::<_, CommsError>::Ok(())
+                };
                 Self::inbox_events(self, evts, loader)
                     .instrument(span!(
                         Level::DEBUG,
@@ -485,6 +496,7 @@ impl MeshSession {
                         data_cnt = num_data
                     ))
                     .await?;
+                ret2?;
             }
             Message::Confirmed(id) => {
                 Self::inbox_confirmed(self, id)
@@ -595,7 +607,7 @@ impl InboxProcessor<Message, ()> for MeshSessionProcessor {
     }
 
     async fn shutdown(&mut self, _sock_addr: MeshConnectAddr) {
-        info!("disconnected: {}:{}", self.addr.host, self.addr.port);
+        debug!("disconnected: {}:{}", self.addr.host, self.addr.port);
         if let Some(session) = self.session.upgrade() {
             session.cancel_commits(CommitErrorKind::Aborted).await;
             session.cancel_sniffers();
