@@ -91,6 +91,12 @@ pub struct MessageFormat {
     pub data: SerializationFormat,
 }
 
+impl std::fmt::Display for MessageFormat {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "meta={}, data={}", self.meta, self.data)
+    }
+}
+
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub enum CentralizedRole {
     Server,
