@@ -1,25 +1,25 @@
 #![cfg_attr(debug_assertions, allow(dead_code, unused_imports))]
 #![allow(unused_imports)]
-use tracing::{error, info, debug};
+use tracing::{debug, error, info};
 
-mod log;
-mod test;
 mod b64;
 mod key;
+mod log;
 mod progress;
+mod test;
 
 pub use super::utils::test::*;
+pub use b64::b16_deserialize;
+pub use b64::b16_serialize;
+pub use b64::b24_deserialize;
+pub use b64::b24_serialize;
+pub use b64::b32_deserialize;
+pub use b64::b32_serialize;
+pub use b64::vec_deserialize;
+pub use b64::vec_serialize;
+pub use key::chain_key_16hex;
+pub use key::chain_key_4hex;
 pub use log::log_init;
 pub use log::obscure_error;
 pub use log::obscure_error_str;
-pub use b64::vec_serialize;
-pub use b64::vec_deserialize;
-pub use b64::b16_serialize;
-pub use b64::b16_deserialize;
-pub use b64::b24_serialize;
-pub use b64::b24_deserialize;
-pub use b64::b32_serialize;
-pub use b64::b32_deserialize;
-pub use key::chain_key_4hex;
-pub use key::chain_key_16hex;
-pub use progress::LoadProgress;
\ No newline at end of file
+pub use progress::LoadProgress;
