@@ -1,11 +1,10 @@
-#![cfg(any(feature = "enable_server", feature = "enable_client" ))]
-use tracing::{info};
-use serde::{Serialize, Deserialize};
+#![cfg(any(feature = "enable_server", feature = "enable_client"))]
 use ate::prelude::*;
+use serde::{Deserialize, Serialize};
+use tracing::info;
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
-struct MyTestObject
-{
+struct MyTestObject {
     firstname: String,
     lastname: String,
     data1: [u8; 32],
@@ -19,10 +18,14 @@ fn load_test() -> Result<(), AteError> {
     ate::utils::bootstrap_test_env();
 
     #[cfg(feature = "enable_mt")]
-    let rt = tokio::runtime::Builder::new_multi_thread().enable_all().build()?;
+    let rt = tokio::runtime::Builder::new_multi_thread()
+        .enable_all()
+        .build()?;
     #[cfg(not(feature = "enable_mt"))]
-    let rt =tokio::runtime::Builder::new_current_thread().enable_all().build()?;
-    
+    let rt = tokio::runtime::Builder::new_current_thread()
+        .enable_all()
+        .build()?;
+
     rt.block_on(TaskEngine::run_until(async {
         // The default configuration will store the redo log locally in the temporary folder
         let mut conf = ConfAte::default();
@@ -32,7 +35,7 @@ fn load_test() -> Result<(), AteError> {
         {
             // We create a chain with a specific key (this is used for the file name it creates)
             let chain = builder.open(&ChainKey::from("load")).await?;
-            
+
             // Prepare
             let session = AteSessionUser::new();
             let mut test_obj = MyTestObject {
@@ -41,7 +44,7 @@ fn load_test() -> Result<(), AteError> {
                 data1: [0 as u8; 32],
                 data2: [1 as u8; 32],
                 data3: [2 as u8; 32],
-                data4: Vec::new()
+                data4: Vec::new(),
             };
             for _ in 0..100 {
                 test_obj.data4.push(1234 as u128);
@@ -71,4 +74,4 @@ fn load_test() -> Result<(), AteError> {
 
         Ok(())
     }))
-}
\ No newline at end of file
+}
